import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.db.MongodbUtil import MongodbUtil
from mns_common.db.v2.MongodbUtilV2 import MongodbUtilV2
import mns_scheduler.extraIncome.one_minute.common.db_create_index as db_create_index
import mns_common.constant.extra_income_db_name as extra_income_db_name
from datetime import datetime
import mns_common.api.k_line.stock_minute_data_api as stock_minute_data_api
import mns_scheduler.extraIncome.one_minute.common.symbol_handle_util as symbol_handle_util

mongodb_util_27017 = MongodbUtil('27017')
mongodbUtilV2_27019 = MongodbUtilV2('27019', extra_income_db_name.EXTRA_INCOME)

main_index_list = [
    "000001.SH",
    "000016.SH",
    "000010.SH",
    "000009.SH",
    "000015.SH",
    "399001.SZ",
    "399004.SZ",
    "399005.SZ",
    "399006.SZ",
    "000300.SH",
    "000905.SH",
    "000688.SH",
    "000903.SH",
    "000906.SH",
    "000852.SH",
    "000932.SH",
    "000933.SH",
    "980017.SZ",
    "399808.SZ",
    "399997.SZ",
]


def sync_main_index_one_minute(data_tag):
    now_date = datetime.now()
    now_day = now_date.strftime('%Y-%m-%d')
    year = now_date.strftime('%Y')
    col_name = extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_MAIN_INDEX + '_' + str(year)
    # 创建索引
    db_create_index.create_index(mongodbUtilV2_27019, col_name)
    for symbol in main_index_list:
        try:
            symbol_prefix = symbol_handle_util.symbol_add_prefix(symbol)
            one_min_df = stock_minute_data_api.get_minute_data(symbol_prefix, now_day, now_day, '1', '')
            one_min_df['symbol'] = symbol
            one_min_df['_id'] = one_min_df['symbol'] + '_' + one_min_df['time']
            if data_frame_util.is_empty(one_min_df) or one_min_df.shape[0] < 241:
                logger.error("当前沪深指数分钟数据同步异常:{}", symbol)
                continue
            else:
                del one_min_df['ava_price']
                if data_tag:
                    mongodbUtilV2_27019.insert_mongo(one_min_df, col_name)
                else:
                    mongodbUtilV2_27019.save_mongo(one_min_df, col_name)
        except BaseException as e:
            logger.error("沪深指数分钟数据同步异常:{},｛｝", symbol, e)
        logger.info("沪深指数分钟数据同步完成:{}", symbol)


if __name__ == '__main__':
    sync_main_index_one_minute(False)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
# 同步当天所有开盘数据
import mns_common.utils.date_handle_util as date_handle_util
from loguru import logger
from datetime import time
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
import mns_common.component.data.data_init_api as data_init_api
import mns_common.utils.db_util as db_util

mongodb_util = MongodbUtil('27017')


def sync_one_day_open_data(str_day):
    realtime_quotes_db_name = 'realtime_quotes_now_' + str_day

    number = db_util.get_realtime_quotes_now_min_number(str_day, None, None)

    query = {"number": number}
    db = db_util.get_db(str_day)
    realtime_quotes_now_list = db.find_query_data(realtime_quotes_db_name, query)

    realtime_quotes_now_one = realtime_quotes_now_list.iloc[0]
    str_now_date = realtime_quotes_now_one['_id']
    str_now_date = str_now_date[7:26]

    now_date = date_handle_util.str_to_date(str_now_date, "%Y-%m-%d %H:%M:%S")
    now_date_time = now_date.time()

    target_time_09_31 = time(9, 31)
    if now_date_time >= target_time_09_31:
        return

    realtime_quotes_now_list['str_day'] = str_day

    realtime_quotes_now_list = handle_init_real_time_quotes_data(
        realtime_quotes_now_list.copy(),
        str_now_date, number)

    mongodb_util.insert_mongo(realtime_quotes_now_list, 'realtime_quotes_now_open')

    logger.info("同步str_day:{}开盘数据", str_day)


def handle_init_real_time_quotes_data(real_time_quotes_now, str_now_date, number):
    #  fix industry
    real_time_quotes_now = company_common_service_new_api.amend_ths_industry(real_time_quotes_now.copy())
    #  exclude b symbol
    real_time_quotes_now = common_service_fun_api.exclude_b_symbol(real_time_quotes_now.copy())
    #  classification symbol
    real_time_quotes_now = common_service_fun_api.classify_symbol(real_time_quotes_now.copy())

    #  calculate parameter
    real_time_quotes_now = data_init_api.calculate_parameter_factor(real_time_quotes_now.copy())

    real_time_quotes_now = real_time_quotes_now.loc[real_time_quotes_now['amount'] != 0]
    real_time_quotes_now['str_now_date'] = str_now_date
    real_time_quotes_now['number'] = number
    return real_time_quotes_now


if __name__ == '__main__':
    sync_one_day_open_data('2025-03-21')



# import sys
# import os
#
# file_path = os.path.abspath(__file__)
# end = file_path.index('mns') + 17
# project_path = file_path[0:end]
# sys.path.append(project_path)
# import mns_common.utils.date_handle_util as date_handle_util
# from datetime import datetime, time, timedelta
# from loguru import logger
# import mns_common.utils.data_frame_util as data_frame_util
# from mns_common.db.MongodbUtil import MongodbUtil
# import mns_common.api.ths.big_deal.ths_big_deal_api as ths_big_deal_api
# import time as sleep_time
# import mns_common.constant.db_name_constant as db_name_constant
#
# mongodb_util = MongodbUtil('27017')
#
#
# #
# def get_last_number(str_day):
#     query = {'str_day': str_day}
#     big_deal_df = mongodb_util.descend_query(query, db_name_constant.BIG_DEAL_NAME, "number", 1)
#     if data_frame_util.is_empty(big_deal_df):
#         return 1
#     else:
#         return list(big_deal_df['number'])[0]
#
#
# def create_index():
#     mongodb_util.create_index(db_name_constant.BIG_DEAL_NAME, [("symbol", 1)])
#     mongodb_util.create_index(db_name_constant.BIG_DEAL_NAME, [("str_day", 1)])
#     mongodb_util.create_index(db_name_constant.BIG_DEAL_NAME, [("symbol", 1), ("str_day", 1)])
#     mongodb_util.create_index(db_name_constant.BIG_DEAL_NAME, [("number", 1), ("str_day", 1)])
#
#
# def sync_ths_big_deal(tag):
#     create_index()
#     now_date_begin = datetime.now()
#     str_day_begin = now_date_begin.strftime('%Y-%m-%d')
#     number = get_last_number(str_day_begin)
#     while True:
#         now_date = datetime.now()
#         begin_date = now_date + timedelta(minutes=-2)
#         if tag or date_handle_util.is_trade_time(now_date):
#             try:
#                 str_day = now_date.strftime('%Y-%m-%d')
#                 str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
#
#                 begin_str_date = begin_date.strftime('%Y-%m-%d %H:%M:%S')
#
#                 target_time_09_30 = time(9, 30)
#                 if now_date.time() < target_time_09_30:
#                     continue
#                 ths_big_deal_df = ths_big_deal_api.stock_fund_flow_big_deal(begin_str_date, str_now_date)
#                 if data_frame_util.is_empty(ths_big_deal_df):
#                     sleep_time.sleep(10)
#                     continue
#                 ths_big_deal_df['str_day'] = ths_big_deal_df['deal_time'].str.slice(0, 10)
#                 ths_big_deal_df = ths_big_deal_df.loc[ths_big_deal_df['str_day'] == str_day]
#                 ths_big_deal_df['number'] = number
#                 ths_big_deal_df['amount_str'] = ths_big_deal_df.amount.astype(str)
#                 ths_big_deal_df['type'] = ths_big_deal_df['type'].replace('买盘', 'buy')
#                 ths_big_deal_df['type'] = ths_big_deal_df['type'].replace("卖盘", "sell")
#
#                 ths_big_deal_df["_id"] = (ths_big_deal_df['deal_time'] + "-" + ths_big_deal_df['symbol'] + "-"
#                                           + ths_big_deal_df['amount_str'] + "-" + ths_big_deal_df['type'])
#                 ths_big_deal_df.drop_duplicates('_id', keep='last', inplace=True)
#                 ths_big_deal_df['sync_str_date'] = str_now_date
#                 # 设置卖盘为负数
#                 ths_big_deal_df.loc[ths_big_deal_df['type'] == 'sell', 'amount'] = -ths_big_deal_df.loc[
#                     ths_big_deal_df['type'] == 'sell', 'amount']
#
#                 ths_big_deal_df['chg'] = ths_big_deal_df['chg'].str.replace('%', '')
#                 ths_big_deal_df['chg'] = ths_big_deal_df['chg'].astype(float)
#
#                 del ths_big_deal_df['amount_str']
#                 exist_code_df = mongodb_util.find_query_data_choose_field(db_name_constant.BIG_DEAL_NAME,
#                                                                           {},
#                                                                           {"_id": 1})
#                 if data_frame_util.is_empty(exist_code_df):
#                     new_df = ths_big_deal_df
#                 else:
#                     exist_code_list = list(exist_code_df['_id'])
#                     new_df = ths_big_deal_df.loc[~(ths_big_deal_df['_id'].isin(exist_code_list))]
#
#                 if data_frame_util.is_empty(new_df):
#                     continue
#                 mongodb_util.insert_mongo(new_df, db_name_constant.BIG_DEAL_NAME)
#                 number = number + 1
#             except Exception as e:
#                 logger.error('策略执行异常:{}', e)
#         elif date_handle_util.is_close_time(now_date):
#             break
#
#
# if __name__ == '__main__':
#     sync_ths_big_deal(False)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

from loguru import logger
import mns_common.component.em.em_stock_info_api as em_stock_info_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.api.xueqiu.xue_qiu_k_line_api as xue_qiu_k_line_api

mongodb_util = MongodbUtil('27017')


def sync_year_k_line():
    global symbol_prefix
    col_name = db_name_constant.STOCK_QFQ_YEAR
    real_time_quotes_all_stocks_df = em_stock_info_api.get_a_stock_info()
    real_time_quotes_all_stocks_df = common_service_fun_api.classify_symbol(real_time_quotes_all_stocks_df)
    for stock_one in real_time_quotes_all_stocks_df.itertuples():
        symbol = stock_one.symbol
        try:
            classification = stock_one.classification
            if classification in ['H', 'K']:
                symbol_prefix = 'SH' + symbol
            elif classification in ['S', 'C']:
                symbol_prefix = 'SZ' + symbol
            elif classification in ['X']:
                symbol_prefix = 'BJ' + symbol

            year_k_line_df = xue_qiu_k_line_api.get_xue_qiu_k_line(symbol_prefix, 'year')
            year_k_line_df = year_k_line_df[[
                'volume',
                'open',
                'high',
                'low',
                'close',
                'chg',
                'percent',
                'turnoverrate',
                'amount',
                'str_day'
            ]]
            year_k_line_df['year'] = year_k_line_df['str_day'].str[:4]

            year_k_line_df["open_to_high_pct"] = (
                    (year_k_line_df["high"] - year_k_line_df["open"]) / year_k_line_df["open"] * 100).round(2)

            year_k_line_df["low_to_high_pct"] = (
                    (year_k_line_df["high"] - year_k_line_df["low"]) / year_k_line_df["low"] * 100).round(2)
            year_k_line_df = year_k_line_df.rename(columns={
                "percent": "chg",
                "chg": "chg_price",
                "turnoverrate": "exchange"
            })
            year_k_line_df['symbol'] = symbol
            year_k_line_df['_id'] = symbol + '_' + year_k_line_df['year']
            mongodb_util.save_mongo(year_k_line_df, col_name)
            logger.info("同步年线数据完成:{},{}", symbol, stock_one.name)
        except BaseException as e:
            logger.error("同步年线数据异常:{},{}", symbol, e)


if __name__ == '__main__':
    sync_year_k_line()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
import mns_common.api.ths.zt.ths_stock_zt_pool_api as ths_stock_zt_pool_api
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger


def update_null_zt_reason(str_day):
    query = {"str_day": str_day, "$or": [{"zt_reason": "0", },
                                         {"zt_reason": ""},
                                         {"zt_reason": float('nan')}]}
    stock_zt_pool_df_null_zt_reason = mongodb_util.find_query_data('stock_zt_pool', query)
    if data_frame_util.is_empty(stock_zt_pool_df_null_zt_reason):
        return None
    no_reason_list = list(stock_zt_pool_df_null_zt_reason['symbol'])
    repeat_number = 0
    # 循环10次
    while len(no_reason_list) > 0 and repeat_number < 10:
        ths_zt_pool_df_data = ths_stock_zt_pool_api.get_zt_reason(str_day)
        for stock_zt_one in stock_zt_pool_df_null_zt_reason.itertuples():
            try:
                ths_pool_zt_reason_one_df = ths_zt_pool_df_data.loc[
                    ths_zt_pool_df_data['symbol'] == stock_zt_one.symbol]
                if data_frame_util.is_not_empty(ths_pool_zt_reason_one_df):
                    stock_zt_pool_df_one_df = stock_zt_pool_df_null_zt_reason.loc[
                        stock_zt_pool_df_null_zt_reason['symbol'] == stock_zt_one.symbol]
                    stock_zt_pool_df_one_df['zt_reason'] = list(ths_pool_zt_reason_one_df['zt_reason'])[0]
                    mongodb_util.save_mongo(stock_zt_pool_df_one_df, 'stock_zt_pool')
                    no_reason_list.remove(stock_zt_one.symbol)
            except BaseException as e:
                logger.error("出现异常:{},{}", stock_zt_one.symbol, e)
                continue
        repeat_number = repeat_number + 1

    return stock_zt_pool_df_null_zt_reason


if __name__ == '__main__':
    update_null_zt_reason('2024-12-12')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
import mns_common.api.ths.company.ths_company_announce_api as ths_company_announce_api
from loguru import logger
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util = MongodbUtil('27017')


# 同步最新公告
# eq-f1001 业绩预告 eq-f1002 重大事项   eq-f1003 股份变动公告

def sync_company_announce():
    page_size = 10
    announce_type_list = ['all', 'eq-f1003', 'eq-f1001', 'eq-f1002']
    for announce_type_one in announce_type_list:
        try:
            get_company_announce(announce_type_one, page_size)
        except BaseException as e:
            logger.error("更新公告出现异常:{}", e)
    logger.info("同步到公告信息完成")


def get_company_announce(announce_type, page_size):
    company_all_df = company_common_service_new_api.get_company_all_info_info()
    de_list_company = company_common_service_new_api.get_de_list_company()
    company_all_df = company_all_df.loc[~(company_all_df['symbol'].isin(de_list_company))]
    for stock_one in company_all_df.itertuples():
        try:
            symbol = stock_one.symbol
            market_id = stock_one.market_id
            # 公告应该不多 只更新一页的数据 页码设置100已经是最大
            page_number = 1
            try:
                ths_company_announce_result = ths_company_announce_api.get_company_announce_info(symbol, market_id,
                                                                                                 announce_type,
                                                                                                 page_size,
                                                                                                 page_number)
            except BaseException as e:
                logger.error("更新公告出现异常:{}.{}", e, symbol)
                continue
            ths_company_announce_result['type'] = announce_type
            ths_company_announce_result['symbol'] = symbol
            ths_company_announce_result['_id'] = ths_company_announce_result['guid'] + '_' + \
                                                 ths_company_announce_result['seq'] + "_" + announce_type
            mongodb_util.save_mongo(ths_company_announce_result, db_name_constant.COMPANY_ANNOUNCE_INFO)

        except BaseException as e:
            logger.error("更新公告出现异常:{}", e)


if __name__ == '__main__':
    sync_company_announce()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import pymongo
from mns_common.utils.async_fun import async_fun
from loguru import logger
import warnings

warnings.filterwarnings("ignore")


class LocalMongodbUtil:
    def __init__(self, port):
        self.port = port

    def get_db(self):
        client = pymongo.MongoClient("mongodb://127.0.0.1:" + '27017' + "/patience")
        return client.patience

    def group(self, query, coll_name):
        db = self.get_db()
        collection = db[coll_name]
        data = collection.aggregate(query)
        return pd.DataFrame(list(data))

    def remove_data(self, query, coll_name):
        db = self.get_db()
        collection = db[coll_name]
        return collection.delete_many(query)

    def exist_data_query(self, coll_name, query):
        db = self.get_db()
        collection = db[coll_name]
        return collection.count(query, limit=1) > 0

    def find_one(self, coll_name, _id):
        db = self.get_db()
        collection = db[coll_name]
        return collection.find_one({'_id': _id})

    def find_one_query(self, coll_name, query):
        db = self.get_db()
        collection = db[coll_name]
        return pd.DataFrame(collection.find_one(query), index=[0])

    def find_all_data(self, coll_name):
        db = self.get_db()
        collection = db[coll_name]
        rows = collection.find({})
        df = pd.DataFrame([basic for basic in rows])
        return df

    def find_query_data(self, coll_name, query):
        db = self.get_db()
        collection = db[coll_name]
        rows = collection.find(query)
        df = pd.DataFrame(list(rows))
        return df

    def find_query_data_choose_field(self, coll_name, query, query_field):
        db = self.get_db()
        collection = db[coll_name]
        rows = collection.find(query, query_field)
        df = pd.DataFrame(list(rows))
        return df

    def find_query_data_list(self, coll_name, query):
        db = self.get_db()
        collection = db[coll_name]
        rows = collection.find(query)
        return list(rows)

    def find_query_data_list(self, coll_name, query):
        db = self.get_db()
        collection = db[coll_name]
        rows = collection.find(query)
        return list(rows)

    def remove_all_data(self, database):
        db = self.get_db()
        collection = db[database]
        query = {"_id": {"$ne": "null"}}
        return collection.delete_many(query)

    def drop_collection(self, database):
        db = self.get_db()
        collection = db[database]
        collection.drop()

    def ascend_query(self, query, coll_name, field, num):
        db = self.get_db()
        collection = db[coll_name]
        return pd.DataFrame(list(collection.find(query).sort(field, 1).skip(0).limit(num)));

    def descend_query(self, query, coll_name, field, num):
        db = self.get_db()
        collection = db[coll_name]
        return pd.DataFrame(list(collection.find(query).sort(field, -1).skip(0).limit(num)));

    def count(self, query, coll_name):
        db = self.get_db()
        collection = db[coll_name]
        return collection.count_documents(query)

    def query_max(self, query, coll_name, field, num):
        db = self.get_db()
        collection = db[coll_name]
        return pd.DataFrame(list(collection.find(query).sort(field, -1).skip(0).limit(num)));

    def query_min(self, query, coll_name, field):
        db = self.get_db()
        collection = db[coll_name]
        return pd.DataFrame(list(collection.find(query).sort(field, 1).skip(0).limit(1)));

    def insert_mongo(self, df, database):
        db = self.get_db()
        if df is None or len(df) == 0:
            return
        collection = db[database]
        # 格式转换
        try:
            df = df.drop_duplicates()
            # df = df.T.drop_duplicates().T
            records = df.to_dict('records')
            collection.insert_many(records)
        except BaseException as e:
            logger.error("插入数据异常:{}", e)

    def insert_mongo_json(self, json, database):
        db = self.get_db()
        collection = db[database]
        # 格式转换
        try:
            collection.insert_many(json)
        except BaseException as e:
            logger.error("插入数据异常:{}", e)

    def save_mongo_json(self, json, database):
        db = self.get_db()
        collection = db[database]
        for record in json:
            try:
                collection.save(record)
            except BaseException as e:
                logger.error("保存数据出现异常:{}", e)

    def save_mongo(self, df, database):
        db = self.get_db()
        if df is None or len(df) == 0:
            return
        collection = db[database]
        # df = df.T.drop_duplicates().T
        # 格式转换
        records = df.to_dict('records')
        for record in records:
            try:
                collection.save(record)
            except BaseException as e:
                logger.error("保存数据出现异常:{},{}", record, e)

    def save_mongo_no_catch_exception(self, df, database):
        db = self.get_db()
        if df is None or len(df) == 0:
            return
        collection = db[database]
        # df = df.T.drop_duplicates().T
        # 格式转换
        records = df.to_dict('records')
        for record in records:
            collection.save(record)

    def update_one(self, df, database):
        db = self.get_db()
        condition = {'_id': list(df['_id'])[0]}
        if len(df) == 0:
            return
        collection = db[database]
        collection.update(condition, df)

    def update_many(self, query, new_values, database):
        db = self.get_db()
        collection = db[database]
        x = collection.update_many(query, new_values)
        return x

    @async_fun
    def update_one_query(self, query, new_values, database):
        db = self.get_db()
        collection = db[database]
        x = collection.update(query, new_values)
        return x

    def distinct_field(self, database, field, query):
        db = self.get_db()
        collection = db[database]
        return collection.distinct(field, query)

    def create_index(self, database, index):
        db = self.get_db()
        collection = db[database]
        collection.create_index(
            index)

    def aggregate(self, pipeline, database):
        db = self.get_db()
        collection = db[database]
        data = collection.aggregate(pipeline)
        return pd.DataFrame(list(data))

    def get_col_keys(self, database):
        db = self.get_db()
        collection = db[database]
        keys = collection.find_one().keys()
        return keys

    # 分页查询 descend 是否降序
    def find_page_skip_data(self, coll_name, page_query, page, page_number, field, descend):
        db = self.get_db()
        collection = db[coll_name]
        if descend:
            sort_tag = -1
        else:
            sort_tag = 1
        rows = collection.find(page_query).sort(field, sort_tag).skip((page - 1) * page_number).limit(page_number)
        df = pd.DataFrame(list(rows))
        return df



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.em.em_stock_info_api as em_stock_info_api
from loguru import logger
import time
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.db.MongodbUtil import MongodbUtil
import mns_scheduler.extraIncome.one_minute.common.symbol_handle_util as symbol_handle_util
from mns_common.db.v2.MongodbUtilV2 import MongodbUtilV2
import mns_scheduler.extraIncome.one_minute.common.db_create_index as db_create_index
import mns_common.constant.extra_income_db_name as extra_income_db_name
import mns_common.api.k_line.stock_minute_data_api as stock_minute_data_api
from datetime import datetime

mongodb_util_27017 = MongodbUtil('27017')
mongodbUtilV2_27019 = MongodbUtilV2('27019', extra_income_db_name.EXTRA_INCOME)


def sync_stock_one_minute(data_tag):
    real_time_quotes_all_stocks = em_stock_info_api.get_a_stock_info()
    real_time_quotes_all_stocks = common_service_fun_api.classify_symbol(real_time_quotes_all_stocks)
    real_time_quotes_all_stocks['symbol'] = real_time_quotes_all_stocks.apply(
        lambda row: row['symbol'] + '.SZ' if row['classification'] in ['S', 'C']
        else row['symbol'] + '.BJ' if row['classification'] in ['X']
        else row['symbol'] + '.SH',
        axis=1)
    # 假设数字格式为 YYYYMMDD
    # debt_real_time_quotes['list_date'] = pd.to_datetime(debt_real_time_quotes['list_date'],
    #                                                     format='%Y%m%d').dt.strftime('%Y-%m-%d')

    real_time_quotes_all_stocks = real_time_quotes_all_stocks.loc[real_time_quotes_all_stocks['amount'] != 0]

    now_date = datetime.now()
    now_day = now_date.strftime('%Y-%m-%d')
    year = now_date.strftime('%Y')

    # 创建索引
    db_create_index.create_index(mongodbUtilV2_27019, extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_C + '_' + str(year))
    db_create_index.create_index(mongodbUtilV2_27019, extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_BJ + '_' + str(year))
    db_create_index.create_index(mongodbUtilV2_27019, extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_H + '_' + str(year))
    db_create_index.create_index(mongodbUtilV2_27019, extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_K + '_' + str(year))
    db_create_index.create_index(mongodbUtilV2_27019, extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_S + '_' + str(year))

    for stock_one in real_time_quotes_all_stocks.itertuples():
        classification = stock_one.classification

        if classification == 'X':
            col_name = extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_BJ
        elif classification == 'S':
            col_name = extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_S
        elif classification == 'H':
            col_name = extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_H
        elif classification == 'K':
            col_name = extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_K
        elif classification == 'C':
            col_name = extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_C
        col_name = col_name + '_' + str(year)

        symbol = stock_one.symbol
        symbol_prefix = symbol_handle_util.symbol_add_prefix(symbol)
        try:
            one_min_df = stock_minute_data_api.get_minute_data(symbol_prefix, now_day, now_day, '1', '')
            one_min_df['symbol'] = symbol
            one_min_df['_id'] = one_min_df['symbol'] + '_' + one_min_df['time']
            if data_frame_util.is_empty(one_min_df) or one_min_df.shape[0] < 241:
                symbol_handle_util.save_fail_data(now_day, symbol_prefix, col_name)
                logger.error("当前股票分钟数据同步异常:{}", symbol)
                continue
            else:
                del one_min_df['ava_price']
                if data_tag:
                    mongodbUtilV2_27019.insert_mongo(one_min_df, col_name)
                else:
                    mongodbUtilV2_27019.save_mongo(one_min_df, col_name)
        except BaseException as e:
            time.sleep(2)
            symbol_handle_util.save_fail_data(now_day, symbol_prefix, col_name)
            logger.error("同步股票分钟数据出现异常:,{},{},{}", e, symbol, now_day)
        logger.info("同步股票分钟票数据完整:{},{}", stock_one.symbol, stock_one.name)


if __name__ == '__main__':
    sync_stock_one_minute()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.api.em.east_money_debt_api as east_money_debt_api
import pandas as pd
from loguru import logger
import time
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.db.MongodbUtil import MongodbUtil
import tushare as ts
from mns_common.db.v2.MongodbUtilV2 import MongodbUtilV2
import mns_scheduler.extraIncome.one_minute.common.db_create_index as db_create_index
import mns_common.constant.extra_income_db_name as extra_income_db_name
mongodb_util_27017 = MongodbUtil('27017')
mongodbUtilV2_27019 = MongodbUtilV2('27019', extra_income_db_name.EXTRA_INCOME)
pro = ts.pro_api('782213d20640249f1dbae50a7f56b22684b8e915a61e435e015579a1')


def get_minute_data(symbol, freq, start_date, end_date):
    # 获取浦发银行60000.SH的历史分钟数据
    df = pro.stk_mins(ts_code=symbol, freq=freq, start_date=start_date, end_date=end_date)
    return df


def sync_kzz_one_minute(trade_date_list_df):
    debt_real_time_quotes = east_money_debt_api.get_debt_real_time_quotes()
    debt_real_time_quotes = classify_symbol(debt_real_time_quotes)
    debt_real_time_quotes['symbol'] = debt_real_time_quotes.apply(
        lambda row: row['symbol'] + '.SZ' if row['classification'] in ['S', 'C']
        else row['symbol'] + '.BJ' if row['classification'] in ['X']
        else row['symbol'] + '.SH',
        axis=1
    )
    # 假设数字格式为 YYYYMMDD
    # debt_real_time_quotes['list_date'] = pd.to_datetime(debt_real_time_quotes['list_date'],
    #                                                     format='%Y%m%d').dt.strftime('%Y-%m-%d')

    db_name = extra_income_db_name.ONE_MINUTE_K_LINE_BFQ_KZZ
    db_create_index.create_index(mongodbUtilV2_27019, db_name)

    for stock_one in debt_real_time_quotes.itertuples():

        trade_date_list_df_copy = trade_date_list_df.copy()

        # list_date = stock_one.list_date
        # trade_date_list_df_copy = trade_date_list_df_copy.loc[trade_date_list_df_copy['_id'] >= list_date]

        symbol = stock_one.symbol

        for i in range(0, len(trade_date_list_df_copy), 28):
            try:
                new_df = trade_date_list_df_copy.iloc[i:i + 28]
                first_df = new_df.iloc[0]  # 第一个 DataFrame
                last_df = new_df.iloc[-1]  # 最后一个 DataFrame
                begin_date = first_df.trade_date + ' 09:20:00'
                end_date = last_df.trade_date + ' 15:00:00'

                df = get_minute_data(symbol, '1min', begin_date, end_date)
                if data_frame_util.is_not_empty(df):
                    df = df.rename(columns={
                        "trade_time": "time",
                        "ts_code": "symbol",
                        "vol": "volume",
                    })
                    df['time_tick'] = df['time'].str[11:19]
                    df = df.loc[df['time_tick'] <= '15:00:00']
                    del df['time_tick']
                    df['_id'] = df['symbol'] + '_' + df['time']
                    mongodbUtilV2_27019.insert_mongo(df, db_name)
            except BaseException as e:
                time.sleep(2)
                first_df = new_df.iloc[0]  # 第一个 DataFrame
                last_df = new_df.iloc[-1]  # 最后一个 DataFrame
                begin_date = first_df.trade_date + ' 09:20:00'
                end_date = last_df.trade_date + ' 15:00:00'
                fail_dict = {'begin_date': begin_date,
                             'end_date': end_date,
                             'symbol': symbol,
                             'db_name': db_name
                             }
                fail_df = pd.DataFrame(fail_dict, index=[1])
                mongodbUtilV2_27019.insert_mongo(fail_df, db_name + '_fail')

                logger.error("同步数据出现异常:{},{},{},{}", e, symbol, begin_date, end_date)
        logger.info("同步完数据:{},{}", stock_one.symbol, stock_one.name)

    return debt_real_time_quotes


def classify_symbol(debt_real_time_quotes_df):
    debt_real_time_quotes_df['classification'] = debt_real_time_quotes_df['market'].apply(
        lambda market: classify_symbol_one(market))
    return debt_real_time_quotes_df


# 单个股票分类
def classify_symbol_one(market):
    if market == 0:
        return 'S'
    else:
        return 'H'


if __name__ == '__main__':
    query_trade = {"$and": [{"trade_date": {"$gte": "2025-03-08"}}, {"trade_date": {"$lte": "2025-03-16"}}]}
    trade_date_list_df_all = mongodb_util_27017.find_query_data('trade_date_list', query_trade)

    sync_kzz_one_minute(trade_date_list_df_all)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.component.em.em_stock_info_api as em_stock_info_api
import akshare as ak
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil
from functools import lru_cache
import mns_common.component.zt.zt_common_service_api as zt_common_service_api

mongodb_util = MongodbUtil('27017')


# 获取陆股通的列表
@lru_cache(maxsize=None)
def get_hk_ggt_component():
    stock_hk_ggt_components_em_df = ak.stock_hk_ggt_components_em()
    stock_hk_ggt_components_em_df = stock_hk_ggt_components_em_df.rename(columns={
        "序号": "index",
        "代码": "symbol",
        "名称": "name"
    })
    return stock_hk_ggt_components_em_df


# 获取em cookie
@lru_cache(maxsize=None)
def get_em_cookie():
    query = {"type": "em_cookie"}
    stock_account_info = mongodb_util.find_query_data(db_name_constant.STOCK_ACCOUNT_INFO, query)
    cookie = list(stock_account_info['cookie'])[0]
    return cookie


def sync_hk_company_industry():
    hk_real_time_df = em_stock_info_api.get_hk_stock_info()

    hk_real_time_df = hk_real_time_df[[
        "symbol",
        "name",
        "chg",
        "total_mv",
        "flow_mv",
        "list_date",
        "industry",
        "amount",
        "now_price"
    ]]
    hk_real_time_df = hk_real_time_df.loc[(hk_real_time_df['total_mv'] != '-')]
    hk_real_time_df['total_mv'] = hk_real_time_df['total_mv'].astype(float)
    hk_real_time_df['flow_mv'] = hk_real_time_df['flow_mv'].astype(float)
    hk_real_time_df = hk_real_time_df.loc[hk_real_time_df['total_mv'] != 0]

    hk_real_time_df.loc[hk_real_time_df['industry'] == '-', 'industry'] = '其他'

    group_industry_df = zt_common_service_api.group_by_industry(hk_real_time_df, 'industry')
    group_industry_df['_id'] = group_industry_df['industry']
    mongodb_util.remove_all_data(db_name_constant.HK_COMPANY_INDUSTRY)
    mongodb_util.save_mongo(group_industry_df, db_name_constant.HK_COMPANY_INDUSTRY)


if __name__ == '__main__':
    sync_hk_company_industry()



def create_index(db_util, col_name):
    index_create = [('symbol', 1), ('time', 1)]
    db_util.create_index(col_name, index_create)
    index_create_01 = [('time', 1)]
    db_util.create_index(col_name, index_create_01)
    index_create_02 = [('symbol', 1)]
    db_util.create_index(col_name, index_create_02)





import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.constant.extra_income_db_name as extra_income_db_name
import pandas as pd
from mns_common.db.v2.MongodbUtilV2 import MongodbUtilV2

mongodbUtilV2_27019 = MongodbUtilV2('27019', extra_income_db_name.EXTRA_INCOME)


def symbol_add_prefix(symbol):
    symbol_simple = symbol[0:6]
    suffix = symbol[7:9]
    if suffix in ['SH']:
        return '1.' + symbol_simple
    elif suffix in ['SZ']:
        return '0.' + symbol_simple
    elif suffix in ['BJ']:
        return '0.' + symbol_simple


# col_name 保存数据的结婚
def save_fail_data(now_day, symbol_prefix, col_name):
    fail_dict = {'begin_date': now_day,
                 'end_date': now_day,
                 'symbol': symbol_prefix,
                 'col_name': col_name,
                 'type': 'kzz',
                 'sync_day': now_day,
                 'valid': True,
                 }
    fail_df = pd.DataFrame(fail_dict, index=[1])
    mongodbUtilV2_27019.insert_mongo(fail_df, extra_income_db_name.ONE_MINUTE_SYNC_FAIL)


if __name__ == '__main__':
    symbol_add_prefix('000001.SZ')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.em.em_stock_info_api as em_stock_info_api
from datetime import datetime
import mns_common.component.self_choose.black_list_service_api as black_list_service_api
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
from loguru import logger
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
from mns_common.constant.black_list_classify_enum import BlackClassify
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.component.tfp.stock_tfp_api as stock_tfp_api

mongodb_util = MongodbUtil('27017')

# 主板 市值最小值 6亿 20个交易日低于5亿退市
MAIN_MARKET_MIN_MV = 600000000

# 创业 科创 北交所 市值最小值 4亿  20个交易日低于3亿退市
SUB_MARKET_MIN_MV = 400000000

# 最小面值 20个交易日低于1元退市
MIN_NOW_PRICE = 1.5

# 主板 120个交易日 参考600万 成交量低于500万股
MAIN_MARKET_MIN_VOLUME = 6000000

# 科创 创业 120个交易日 参考300万 成交量低于200万股
SUB_MARKET_MIN_VOLUME = 3000000

# 北交所 120个交易日 参考150万 成交量低于100万股
BJS_MARKET_MIN_VOLUME = 1500000


def transactions_check_task():
    # 获取当前日期和时间
    now = datetime.now()

    # 格式化输出
    now_day_str = now.strftime("%Y%m%d")

    now_day_number = float(now_day_str)

    real_time_quotes_now = em_stock_info_api.get_a_stock_info()
    real_time_quotes_now['list_date'] = real_time_quotes_now['list_date'].fillna(99999999)
    real_time_quotes_now = real_time_quotes_now.loc[real_time_quotes_now['list_date'] <= now_day_number]
    real_time_quotes_now = common_service_fun_api.classify_symbol(real_time_quotes_now)
    real_time_quotes_now = common_service_fun_api.exclude_ts_symbol(real_time_quotes_now)
    # 排除交易金额为0的
    real_time_quotes_now = common_service_fun_api.exclude_amount_zero_stock(real_time_quotes_now)

    de_list_symbol = company_common_service_new_api.get_de_list_company()

    real_time_quotes_now = real_time_quotes_now.loc[~(real_time_quotes_now['symbol'].isin(de_list_symbol))]

    query = {"up_level_code": BlackClassify.TRANSACTIONS.level_code}
    tag = mongodb_util.remove_data(query, db_name_constant.SELF_BLACK_STOCK)
    success = tag.acknowledged
    if success:

        for stock_one in real_time_quotes_now.itertuples():
            try:
                total_mv_check(stock_one)
                now_price_check(stock_one)
                volume_check(stock_one)
            except BaseException as e:
                logger.error("交易风险校验异常:{},{}", e, stock_one.symbol)


# 总市值check
def total_mv_check(stock_one):
    classification = stock_one.classification
    total_mv = stock_one.total_mv
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    key_id = stock_one.symbol + "_" + BlackClassify.MV_RISK.level_code
    tag = False
    if classification in ['S', 'H'] and total_mv < MAIN_MARKET_MIN_MV:
        tag = True
    elif classification in ['K', 'C', "X"] and total_mv < SUB_MARKET_MIN_MV:
        tag = True

    if tag:
        black_list_service_api.save_black_stock(
            key_id,
            stock_one.symbol,
            stock_one.name,
            str_day,
            str_now_date,
            BlackClassify.MV_RISK.level_name + ":" + str(
                round(total_mv / common_service_fun_api.HUNDRED_MILLION, 2)) + "亿",
            BlackClassify.MV_RISK.level_name + ":" + str(
                round(total_mv / common_service_fun_api.HUNDRED_MILLION, 2)) + "亿",
            "",
            BlackClassify.MV_RISK.up_level_code,
            BlackClassify.MV_RISK.up_level_name,
            BlackClassify.MV_RISK.level_code,
            BlackClassify.MV_RISK.level_name,
        )


# 当前面值check
def now_price_check(stock_one):
    now_price = stock_one.now_price
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')

    tfp_symbol_list = stock_tfp_api.get_stock_tfp_symbol_list_by_day(str_day)
    if stock_one.symbol in tfp_symbol_list:
        return

    key_id = stock_one.symbol + "_" + BlackClassify.CLOSE_PRICE_RISK.level_code
    if MIN_NOW_PRICE > now_price > 0:
        black_list_service_api.save_black_stock(
            key_id,
            stock_one.symbol,
            stock_one.name,
            str_day,
            str_now_date,
            BlackClassify.CLOSE_PRICE_RISK.level_name + ":当前价格" + str(now_price),
            BlackClassify.CLOSE_PRICE_RISK.level_name + ":当前价格" + str(now_price),
            "",
            BlackClassify.CLOSE_PRICE_RISK.up_level_code,
            BlackClassify.CLOSE_PRICE_RISK.up_level_name,
            BlackClassify.CLOSE_PRICE_RISK.level_code,
            BlackClassify.CLOSE_PRICE_RISK.level_name,
        )


#
def volume_check(stock_one):
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    trade_date_120 = trade_date_common_service_api.get_before_trade_date(str_day, 120)
    query = {'date': {"$gte": date_handle_util.no_slash_date(trade_date_120)}, 'symbol': stock_one.symbol}
    stock_qfq_daily_df = mongodb_util.find_query_data(db_name_constant.STOCK_QFQ_DAILY, query)
    if stock_qfq_daily_df.shape[0] < 120:
        return
    # volume 单位是100股
    sum_volume = sum(stock_qfq_daily_df['volume']) * 100
    key_id = stock_one.symbol + "_" + BlackClassify.AMOUNT_RISK.level_code
    tag = False
    classification = stock_one.classification
    if classification in ['S', 'H'] and sum_volume < MAIN_MARKET_MIN_VOLUME:
        tag = True

    elif classification in ['K', 'C'] and sum_volume < SUB_MARKET_MIN_VOLUME:
        tag = True

    elif classification in ['X'] and sum_volume < BJS_MARKET_MIN_VOLUME:
        tag = True

    if tag:
        black_list_service_api.save_black_stock(
            key_id,
            stock_one.symbol,
            stock_one.name,
            str_day,
            str_now_date,
            BlackClassify.AMOUNT_RISK.level_name + ":120个交易日成交量:" + str(
                round(sum_volume / common_service_fun_api.TEN_THOUSAND), 0) + "万股",
            BlackClassify.AMOUNT_RISK.level_name + ":120个交易日成交量:" + str(
                round(sum_volume / common_service_fun_api.TEN_THOUSAND), 0) + "万股",
            "",
            BlackClassify.AMOUNT_RISK.up_level_code,
            BlackClassify.AMOUNT_RISK.up_level_name,
            BlackClassify.AMOUNT_RISK.level_code,
            BlackClassify.AMOUNT_RISK.level_name,
        )


if __name__ == '__main__':
    transactions_check_task()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.em.em_stock_info_api as em_stock_info_api
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_scheduler.k_line.month_week_daily.daily_week_month_line_sync as daily_week_month_line_sync
from datetime import datetime
import mns_scheduler.zt.zt_pool.em_zt_pool_sync_api as em_zt_pool_sync_api
import mns_scheduler.zt.high_chg.sync_high_chg_pool_service as sync_high_chg_pool_service
import mns_scheduler.zt.open_data.kcx_high_chg_open_data_sync as kcx_high_chg_open_data_sync
import mns_scheduler.zt.high_chg.sync_high_chg_real_time_quotes_service as sync_high_chg_real_time_quotes_service


def sync_now_day_high_chg():
    real_time_quotes_now_es = em_stock_info_api.get_a_stock_info()
    real_time_quotes_now_es_high_chg = real_time_quotes_now_es.loc[
        real_time_quotes_now_es['chg'] > common_service_fun_api.ZT_CHG]
    # 同步qfq k线
    daily_week_month_line_sync.sync_all_daily_data('daily', 'qfq', 'stock_qfq_daily', None,
                                                   list(real_time_quotes_now_es_high_chg['symbol']))

    now_date = datetime.now()

    str_now_day = now_date.strftime('%Y-%m-%d')
    # 同步当前涨停
    em_zt_pool_sync_api.save_zt_info(str_now_day)

    # 同步涨幅列表
    sync_high_chg_pool_service.sync_stock_high_chg_pool_list(str_now_day, None)

    # 同步kcx 集合竞价数据
    kcx_high_chg_open_data_sync.sync_all_kc_zt_data(str_now_day, None)
    # 同步实时行情数据
    sync_high_chg_real_time_quotes_service.sync_high_chg_real_time_quotes(str_now_day)


if __name__ == '__main__':
    sync_now_day_high_chg()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import akshare as ak
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.data_frame_util as data_frame_util

mongodb_util = MongodbUtil('27017')
import mns_common.constant.db_name_constant as db_name_constant
import mns_scheduler.finance.finance_common_api as finance_common_api
from loguru import logger


# 利润表
#  "_id" : ObjectId("6644085f608b7737dee21a3a"),
#     "SECUCODE" : "600519.SH",
#     "SECURITY_CODE" : "600519",
#     "SECURITY_NAME_ABBR" : "贵州茅台",
#     "ORG_CODE" : "10002602",
#     "ORG_TYPE" : "通用",
#     "REPORT_DATE" : "2023-12-31 00:00:00",
#     "REPORT_TYPE" : "年报",
#     "REPORT_DATE_NAME" : "2023年报",
#     "SECURITY_TYPE_CODE" : "058001001",
#     "NOTICE_DATE" : "2024-04-03 00:00:00",
#     "UPDATE_DATE" : "2024-04-03 00:00:00",
#     "CURRENCY" : "CNY",
#     "TOTAL_OPERATE_INCOME" : 150560330316.45,  营业总收入
#     "TOTAL_OPERATE_INCOME_YOY" : 18.0365792459, 总运营收入修正
#     "OPERATE_INCOME" : 147693604994.14,  营业收入
#     "OPERATE_INCOME_YOY" : 19.0119185529, 营业收入修正
#     "INTEREST_INCOME" : 2866725322.31, 利息收入
#     "INTEREST_INCOME_YOY" : 利息收入修正
#     "EARNED_PREMIUM" : NaN,
#     "EARNED_PREMIUM_YOY" : NaN,
#     "FEE_COMMISSION_INCOME" : NaN,
#     "FEE_COMMISSION_INCOME_YOY" : NaN,
#     "OTHER_BUSINESS_INCOME" : NaN,
#     "OTHER_BUSINESS_INCOME_YOY" : NaN,
#     "TOI_OTHER" : NaN,
#     "TOI_OTHER_YOY" : NaN,
#     "TOTAL_OPERATE_COST" : 46960889468.54, 营业总成本
#     "TOTAL_OPERATE_COST_YOY" : 18.1456266222,
#     "OPERATE_COST" : 11867273851.78, 营业成本
#     "OPERATE_COST_YOY" : 17.5737925437,
#     "INTEREST_EXPENSE" : 113500129.93, 利息支出
#     "INTEREST_EXPENSE_YOY" : 7.4972611642,
#     "FEE_COMMISSION_EXPENSE" : 68578.57,  手续费及佣金支出
#     "FEE_COMMISSION_EXPENSE_YOY" : -52.0903684752,
#     "RESEARCH_EXPENSE" : 157371873.01, 研发费用
#     "RESEARCH_EXPENSE_YOY" : 16.4116440028,
#     "SURRENDER_VALUE" : NaN,
#     "SURRENDER_VALUE_YOY" : NaN,
#     "NET_COMPENSATE_EXPENSE" : NaN,
#     "NET_COMPENSATE_EXPENSE_YOY" : NaN,
#     "NET_CONTRACT_RESERVE" : NaN,
#     "NET_CONTRACT_RESERVE_YOY" : NaN,
#     "POLICY_BONUS_EXPENSE" : NaN,
#     "POLICY_BONUS_EXPENSE_YOY" : NaN,
#     "REINSURE_EXPENSE" : NaN,
#     "REINSURE_EXPENSE_YOY" : NaN,
#     "OTHER_BUSINESS_COST" : NaN,
#     "OTHER_BUSINESS_COST_YOY" : NaN,
#     "OPERATE_TAX_ADD" : 22234175898.6, 税金及附加
#     "OPERATE_TAX_ADD_YOY" : 20.2119055043,
#     "SALE_EXPENSE" : 4648613585.82, 销售费用
#     "SALE_EXPENSE_YOY" : 40.9642928475,
#     "MANAGE_EXPENSE" : 9729389252.31, 管理费用
#     "MANAGE_EXPENSE_YOY" : 7.9580889133,
#     "ME_RESEARCH_EXPENSE" : NaN,
#     "ME_RESEARCH_EXPENSE_YOY" : NaN,
#     "FINANCE_EXPENSE" : -1789503701.48, 财务费用
#     "FINANCE_EXPENSE_YOY" : -28.5742355094,
#     "FE_INTEREST_EXPENSE" : 12624628.35, 利息费用
#     "FE_INTEREST_EXPENSE_YOY" : 5.0021902771,
#     "FE_INTEREST_INCOME" : 1942301920.98, 利息收入
#     "FE_INTEREST_INCOME_YOY" : 31.6437955552,
#     "ASSET_IMPAIRMENT_LOSS" : NaN,
#     "ASSET_IMPAIRMENT_LOSS_YOY" : NaN,
#     "CREDIT_IMPAIRMENT_LOSS" : NaN,
#     "CREDIT_IMPAIRMENT_LOSS_YOY" : NaN,
#     "TOC_OTHER" : NaN,
#     "TOC_OTHER_YOY" : NaN,
#     "FAIRVALUE_CHANGE_INCOME" : 3151962.5, :公允价值变动收益
#     "FAIRVALUE_CHANGE_INCOME_YOY" : NaN,
#     "INVEST_INCOME" : 34025967.82, 投资收益
#     "INVEST_INCOME_YOY" : -46.7011782268,
#     "INVEST_JOINT_INCOME" : NaN,
#     "INVEST_JOINT_INCOME_YOY" : NaN,
#     "NET_EXPOSURE_INCOME" : NaN,
#     "NET_EXPOSURE_INCOME_YOY" : NaN,
#     "EXCHANGE_INCOME" : NaN,
#     "EXCHANGE_INCOME_YOY" : NaN,
#     "ASSET_DISPOSAL_INCOME" : -479736.97, 资产处置收益
#     "ASSET_DISPOSAL_INCOME_YOY" : -324.9796785895,
#     "ASSET_IMPAIRMENT_INCOME" : NaN,
#     "ASSET_IMPAIRMENT_INCOME_YOY" : NaN,
#     "CREDIT_IMPAIRMENT_INCOME" : 37871293.26, 信用减值损失(新)
#     "CREDIT_IMPAIRMENT_INCOME_YOY" : 357.8638477375,
#     "OTHER_INCOME" : 34644873.86, 其他收益
#     "OTHER_INCOME_YOY" : 41.3767542405,
#     "OPERATE_PROFIT_OTHER" : NaN,
#     "OPERATE_PROFIT_OTHER_YOY" : NaN,
#     "OPERATE_PROFIT_BALANCE" : 0.0,
#     "OPERATE_PROFIT_BALANCE_YOY" : NaN,
#     "OPERATE_PROFIT" : 103708655208.38, 营业利润
#     "OPERATE_PROFIT_YOY" : 18.0123117479,
#     "NONBUSINESS_INCOME" : 86779655.95, 加:营业外收入
#     "NONBUSINESS_INCOME_YOY" : 22.4796849672,
#     "NONCURRENT_DISPOSAL_INCOME" : NaN,
#     "NONCURRENT_DISPOSAL_INCOME_YOY" : NaN,
#     "NONBUSINESS_EXPENSE" : 132881174.52, 减:营业外支出
#     "NONBUSINESS_EXPENSE_YOY" : -46.6092621953,
#     "NONCURRENT_DISPOSAL_LOSS" : NaN,
#     "NONCURRENT_DISPOSAL_LOSS_YOY" : NaN,
#     "EFFECT_TP_OTHER" : NaN,
#     "EFFECT_TP_OTHER_YOY" : NaN,
#     "TOTAL_PROFIT_BALANCE" : 0.0,
#     "TOTAL_PROFIT_BALANCE_YOY" : NaN,
#     "TOTAL_PROFIT" : 103662553689.81, 利润总额
#     "TOTAL_PROFIT_YOY" : 18.1993076599,
#     "INCOME_TAX" : 26141077412.01, 减:所得税
#     "INCOME_TAX_YOY" : 17.0909328034,
#     "EFFECT_NETPROFIT_OTHER" : NaN,
#     "EFFECT_NETPROFIT_OTHER_YOY" : NaN,
#     "EFFECT_NETPROFIT_BALANCE" : NaN,
#     "EFFECT_NETPROFIT_BALANCE_YOY" : NaN,
#     "UNCONFIRM_INVEST_LOSS" : NaN,
#     "UNCONFIRM_INVEST_LOSS_YOY" : NaN,
#     "NETPROFIT" : 77521476277.8, 净利润
#     "NETPROFIT_YOY" : 18.5778097415,
#     "PRECOMBINE_PROFIT" : NaN,
#     "PRECOMBINE_PROFIT_YOY" : NaN,
#     "CONTINUED_NETPROFIT" : 77521476277.8, 持续经营净利润
#     "CONTINUED_NETPROFIT_YOY" : 18.5778097415,
#     "DISCONTINUED_NETPROFIT" : NaN,
#     "DISCONTINUED_NETPROFIT_YOY" : NaN,
#     "PARENT_NETPROFIT" : 74734071550.75, 归属于母公司股东的净利润
#     "PARENT_NETPROFIT_YOY" : 19.1598992892,
#     "MINORITY_INTEREST" : 2787404727.05,  少数股东损益
#     "MINORITY_INTEREST_YOY" : 4.8459336455,
#     "DEDUCT_PARENT_NETPROFIT" : 74752564425.52, 扣除非经常性损益后的净利润
#     "DEDUCT_PARENT_NETPROFIT_YOY" : 19.0462109566,
#     "NETPROFIT_OTHER" : NaN,
#     "NETPROFIT_OTHER_YOY" : NaN,
#     "NETPROFIT_BALANCE" : NaN,
#     "NETPROFIT_BALANCE_YOY" : NaN,
#     "BASIC_EPS" : 59.49,  基本每股收益
#     "BASIC_EPS_YOY" : 19.1468055277,
#     "DILUTED_EPS" : 59.49,  稀释每股收益
#     "DILUTED_EPS_YOY" : 19.1468055277,
#     "OTHER_COMPRE_INCOME" : 4715179.82, 其他综合收益
#     "OTHER_COMPRE_INCOME_YOY" : 110.40766101,
#     "PARENT_OCI" : 4715179.82, 归属于母公司股东的其他综合收益
#     "PARENT_OCI_YOY" : 110.40766101,
#     "MINORITY_OCI" : NaN,
#     "MINORITY_OCI_YOY" : NaN,
#     "PARENT_OCI_OTHER" : NaN,
#     "PARENT_OCI_OTHER_YOY" : NaN,
#     "PARENT_OCI_BALANCE" : NaN,
#     "PARENT_OCI_BALANCE_YOY" : NaN,
#     "UNABLE_OCI" : NaN,
#     "UNABLE_OCI_YOY" : NaN,
#     "CREDITRISK_FAIRVALUE_CHANGE" : NaN,
#     "CREDITRISK_FAIRVALUE_CHANGE_YOY" : NaN,
#     "OTHERRIGHT_FAIRVALUE_CHANGE" : NaN,
#     "OTHERRIGHT_FAIRVALUE_CHANGE_YOY" : NaN,
#     "SETUP_PROFIT_CHANGE" : NaN,
#     "SETUP_PROFIT_CHANGE_YOY" : NaN,
#     "RIGHTLAW_UNABLE_OCI" : NaN,
#     "RIGHTLAW_UNABLE_OCI_YOY" : NaN,
#     "UNABLE_OCI_OTHER" : NaN,
#     "UNABLE_OCI_OTHER_YOY" : NaN,
#     "UNABLE_OCI_BALANCE" : NaN,
#     "UNABLE_OCI_BALANCE_YOY" : NaN,
#     "ABLE_OCI" : 4715179.82,
#     "ABLE_OCI_YOY" : 110.40766101,
#     "RIGHTLAW_ABLE_OCI" : NaN,
#     "RIGHTLAW_ABLE_OCI_YOY" : NaN,
#     "AFA_FAIRVALUE_CHANGE" : NaN,
#     "AFA_FAIRVALUE_CHANGE_YOY" : NaN,
#     "HMI_AFA" : NaN,
#     "HMI_AFA_YOY" : NaN,
#     "CASHFLOW_HEDGE_VALID" : NaN,
#     "CASHFLOW_HEDGE_VALID_YOY" : NaN,
#     "CREDITOR_FAIRVALUE_CHANGE" : NaN,
#     "CREDITOR_FAIRVALUE_CHANGE_YOY" : NaN,
#     "CREDITOR_IMPAIRMENT_RESERVE" : NaN,
#     "CREDITOR_IMPAIRMENT_RESERVE_YOY" : NaN,
#     "FINANCE_OCI_AMT" : NaN,
#     "FINANCE_OCI_AMT_YOY" : NaN,
#     "CONVERT_DIFF" : 4715179.82,
#     "CONVERT_DIFF_YOY" : 110.40766101,
#     "ABLE_OCI_OTHER" : NaN,
#     "ABLE_OCI_OTHER_YOY" : NaN,
#     "ABLE_OCI_BALANCE" : NaN,
#     "ABLE_OCI_BALANCE_YOY" : NaN,
#     "OCI_OTHER" : NaN,
#     "OCI_OTHER_YOY" : NaN,
#     "OCI_BALANCE" : NaN,
#     "OCI_BALANCE_YOY" : NaN,
#     "TOTAL_COMPRE_INCOME" : 77526191457.62, 综合收益总额
#     "TOTAL_COMPRE_INCOME_YOY" : 18.5809573963,
#     "PARENT_TCI" : 74738786730.57, 归属于母公司股东的综合收益总额
#     "PARENT_TCI_YOY" : 19.1631595692,
#     "MINORITY_TCI" : 2787404727.05,  归属于少数股东的综合收益总额
#     "MINORITY_TCI_YOY" : 4.8459336455,
#     "PRECOMBINE_TCI" : NaN,
#     "PRECOMBINE_TCI_YOY" : NaN,
#     "EFFECT_TCI_BALANCE" : NaN,
#     "EFFECT_TCI_BALANCE_YOY" : NaN,
#     "TCI_OTHER" : NaN,
#     "TCI_OTHER_YOY" : NaN,
#     "TCI_BALANCE" : NaN,
#     "TCI_BALANCE_YOY" : NaN,
#     "ACF_END_INCOME" : NaN,
#     "ACF_END_INCOME_YOY" : NaN,
#     "OPINION_TYPE" : "标准无保留意见" 审计意见(境内)
# https://emweb.securities.eastmoney.com/PC_HSF10/NewFinanceAnalysis/Index?type=web&code=sh600519#lrb-0
def get_em_profit_api(symbol):
    sec_code = finance_common_api.get_sec_code(symbol)
    try:
        stock_profit_sheet_by_report_em = ak.stock_profit_sheet_by_report_em(sec_code)
    except Exception as e:
        logger.error("同步利润表异常:{},{}", symbol, e)
    if data_frame_util.is_empty(stock_profit_sheet_by_report_em.copy()):
        return None
    stock_profit_sheet_by_report_em = check_columns(stock_profit_sheet_by_report_em)
    stock_profit_sheet_by_report_em = stock_profit_sheet_by_report_em[[
        "SECUCODE",
        "SECURITY_CODE",
        "SECURITY_NAME_ABBR",
        "ORG_CODE",
        "ORG_TYPE",
        "REPORT_DATE",
        "REPORT_TYPE",
        "REPORT_DATE_NAME",
        "SECURITY_TYPE_CODE",
        "NOTICE_DATE",
        "UPDATE_DATE",
        "CURRENCY",
        "TOTAL_OPERATE_INCOME",
        "OPERATE_INCOME",
        "INTEREST_INCOME",
        "TOTAL_OPERATE_COST",
        "OPERATE_COST",
        "INTEREST_EXPENSE",
        "FEE_COMMISSION_EXPENSE",
        "RESEARCH_EXPENSE",
        "OPERATE_TAX_ADD",
        "SALE_EXPENSE",
        "MANAGE_EXPENSE",
        "FINANCE_EXPENSE",
        "FE_INTEREST_EXPENSE",
        "FE_INTEREST_INCOME",
        "FAIRVALUE_CHANGE_INCOME",
        "INVEST_INCOME",
        "ASSET_DISPOSAL_INCOME",
        "CREDIT_IMPAIRMENT_INCOME",
        "OTHER_INCOME",
        "OPERATE_PROFIT",
        "NONBUSINESS_INCOME",
        "NONBUSINESS_EXPENSE",
        "TOTAL_PROFIT",
        "INCOME_TAX",
        "NETPROFIT",
        "CONTINUED_NETPROFIT",
        "PARENT_NETPROFIT",
        'MINORITY_INTEREST',
        'DEDUCT_PARENT_NETPROFIT',
        'BASIC_EPS',
        'DILUTED_EPS',
        'OTHER_COMPRE_INCOME',
        'PARENT_OCI',
        'TOTAL_COMPRE_INCOME',
        'PARENT_TCI',
        'MINORITY_TCI',
        'OPINION_TYPE'
    ]]
    stock_profit_sheet_by_report_em['_id'] = (stock_profit_sheet_by_report_em['SECURITY_CODE']
                                              + "_" + stock_profit_sheet_by_report_em['REPORT_DATE'])

    query = {'SECURITY_CODE': symbol}
    exist_profit_em_df = mongodb_util.find_query_data(db_name_constant.EM_STOCK_PROFIT, query)
    if data_frame_util.is_not_empty(exist_profit_em_df):
        new_profit_df = stock_profit_sheet_by_report_em.loc[
            ~(stock_profit_sheet_by_report_em['_id'].isin(list(exist_profit_em_df['_id'])))]
    else:
        new_profit_df = stock_profit_sheet_by_report_em
    if data_frame_util.is_empty(new_profit_df):
        return None
    new_profit_df = new_profit_df.fillna(0)
    return new_profit_df


def check_columns(profit_df):
    if 'TOTAL_OPERATE_INCOME' not in profit_df.columns:
        profit_df = profit_df.assign(TOTAL_OPERATE_INCOME=0)

    if 'FAIRVALUE_CHANGE_INCOME' not in profit_df.columns:
        profit_df = profit_df.assign(FAIRVALUE_CHANGE_INCOME=0)

    if 'INTEREST_INCOME' not in profit_df.columns:
        profit_df = profit_df.assign(INTEREST_INCOME=0)
    if 'TOTAL_OPERATE_COST' not in profit_df.columns:
        profit_df = profit_df.assign(TOTAL_OPERATE_COST=0)
    if 'OPERATE_COST' not in profit_df.columns:
        profit_df = profit_df.assign(OPERATE_COST=0)
    if 'INTEREST_EXPENSE' not in profit_df.columns:
        profit_df = profit_df.assign(INTEREST_EXPENSE=0)
    if 'FEE_COMMISSION_EXPENSE' not in profit_df.columns:
        profit_df = profit_df.assign(FEE_COMMISSION_EXPENSE=0)
    if 'RESEARCH_EXPENSE' not in profit_df.columns:
        profit_df = profit_df.assign(RESEARCH_EXPENSE=0)
    if 'SALE_EXPENSE' not in profit_df.columns:
        profit_df = profit_df.assign(SALE_EXPENSE=0)
    if 'MANAGE_EXPENSE' not in profit_df.columns:
        profit_df = profit_df.assign(MANAGE_EXPENSE=0)
    if 'FINANCE_EXPENSE' not in profit_df.columns:
        profit_df = profit_df.assign(FINANCE_EXPENSE=0)
    if 'FE_INTEREST_EXPENSE' not in profit_df.columns:
        profit_df = profit_df.assign(FE_INTEREST_EXPENSE=0)
    if 'FE_INTEREST_INCOME' not in profit_df.columns:
        profit_df = profit_df.assign(FE_INTEREST_INCOME=0)
    if 'CREDIT_IMPAIRMENT_INCOME' not in profit_df.columns:
        profit_df = profit_df.assign(CREDIT_IMPAIRMENT_INCOME=0)
    if 'ACCOUNTS_RECE' not in profit_df.columns:
        profit_df = profit_df.assign(ACCOUNTS_RECE=0)
    if 'LOAN_ADVANCE' not in profit_df.columns:
        profit_df = profit_df.assign(LOAN_ADVANCE=0)
    if 'MONETARYFUNDS' not in profit_df.columns:
        profit_df = profit_df.assign(MONETARYFUNDS=0)
    return profit_df


import mns_common.component.em.em_stock_info_api as em_stock_info_api

if __name__ == '__main__':
    get_em_profit_api('002193')
    em_df = em_stock_info_api.get_a_stock_info()
    for em_one in em_df.itertuples():
        try:
            get_em_profit_api(em_one.symbol)
        except Exception as e:
            logger.error("同步利润表异常:{},{}", em_one.symbol, e)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger
import mns_scheduler.k_line.clean.k_line_info_clean_task as k_line_info_clean_task

mongodb_util = MongodbUtil('27017')


def clean_history_data():
    query = {"$and": [{"trade_date": {"$gte": '2023-11-06'}}, {"trade_date": {"$lte": '2024-09-12'}}]}
    trade_date_list_df = mongodb_util.find_query_data('trade_date_list', query)
    trade_date_list_df = trade_date_list_df.sort_values(by=['trade_date'], ascending=False)
    for trade_data_one in trade_date_list_df.itertuples():
        try:
            k_line_info_clean_task.sync_k_line_info_task(trade_data_one.trade_date)
            logger.info("清洗数据到:{}", trade_data_one.trade_date)
        except BaseException as e:
            logger.error("发生异常:{},{}", trade_data_one.trade_date, e)


if __name__ == '__main__':
    clean_history_data()
    # k_line_info_clean_task.sync_k_line_info('2025-02-14', None)
    # clean_history_data()
    # k_line_info_clean_task.sync_k_line_info('2025-02-21', None)
    # k_line_info_clean_task.sync_k_line_info('2025-03-26', ['301601'])
    # clean_history_data()
    # k_line_info_clean_task.sync_k_line_info('2025-03-11', None)
    # k_line_info_clean_task.sync_k_line_info('2025-03-13', None)

    # 001389  001359
    # k_line_info_clean_task.sync_k_line_info('2025-02-14', None)
    # k_line_info_clean_task.sync_k_line_info('2025-02-17', None)

    # clean_history_data()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_scheduler.extraIncome.one_minute.index.main_index_sync_task as main_index_sync_task
import mns_scheduler.extraIncome.one_minute.etf.etf_one_minute_sync_task as etf_one_minute_sync_task
import mns_scheduler.extraIncome.one_minute.kzz.kzz_one_minute_sync_task as kzz_one_minute_sync_task
import mns_scheduler.extraIncome.one_minute.stock.stock_one_minute_sync_task as stock_one_minute_sync_task
from datetime import datetime
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api


def sync_one_minute_data():
    now_date = datetime.now()
    hour = now_date.hour
    now_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(now_day):
        if 15 < hour < 20:
            main_index_sync_task.sync_main_index_one_minute(True)
            etf_one_minute_sync_task.sync_etf_one_minute(True)
            kzz_one_minute_sync_task.sync_kzz_one_minute(True)
            stock_one_minute_sync_task.sync_stock_one_minute(True)
        elif hour < 9 or hour >= 20:
            main_index_sync_task.sync_main_index_one_minute(False)
            etf_one_minute_sync_task.sync_etf_one_minute(False)
            kzz_one_minute_sync_task.sync_kzz_one_minute(False)
            stock_one_minute_sync_task.sync_stock_one_minute(False)


if __name__ == '__main__':
    sync_one_minute_data()
